public with sharing class TestFieldValidation {
    
    public void testFieldValidation(){
    	ESignLiveSDK sdk = new ESignLiveSDK();
         
        //Create package
        ESignLiveAPIObjects.Package_x pkg = new ESignLiveAPIObjects.Package_x();
        pkg.name = 'Test Field Validator - ' + Datetime.now().format();
        pkg.status = ESignLiveAPIObjects.PackageStatus.SENT;
        
        //Create Roles
        String roleId1 = 'manager';
        ESignLiveAPIObjects.Role role1 = new ESignLiveAPIObjects.Role();
        role1.signers = sdk.createRolesSigner('sigenr1_firstname', 'signer1_lastname', 'signer1@mailinator.com', 'manager', 'ABC Bank');
        role1.id = roleId1;
        role1.name = roleId1;
        
        String roleId2 = 'client';
        ESignLiveAPIObjects.Role role2 = new ESignLiveAPIObjects.Role();
        role2.signers = sdk.createRolesSigner('sigenr2_firstname', 'signer2_lastname', 'signer2@mailinator.com', 'client', 'ABC Company');
        role2.id = roleId2;
        role2.name = roleId2;
        
        pkg.roles = new List<ESignLiveAPIObjects.Role>{role1,role2};    //add role

        //Prepare Documents Blob
        String document1Name = 'Sample_Position_Extraction';
        StaticResource sr = [SELECT Id, Body FROM StaticResource WHERE Name = 'test_field_validator' LIMIT 1];
        Map<String,Blob> documentBlobMap = new Map<String,Blob>();
        documentBlobMap.put(document1Name, sr.Body);
         
        //Create Document Metadata
        ESignLiveAPIObjects.Document document1 = new ESignLiveAPIObjects.Document();
        document1.name = document1Name;
        document1.id = document1Name;
        document1.extract = true;		//document level extraction:true
        
        
        //Approval for client
        ESignLiveAPIObjects.Approval approvalForClient = new ESignLiveAPIObjects.Approval();
        approvalForClient.role = roleId2;
        approvalForClient.id = 'approvalForClient';
        
        //signature field for client
        ESignLiveAPIObjects.Field fieldClient1 = new ESignLiveAPIObjects.Field();
        fieldClient1.extract = true;
        fieldClient1.name = 'client_signature';		//match pdf field property name
        fieldClient1.type = 'SIGNATURE';
        fieldClient1.subtype = 'CAPTURE';
        
        //date field for client
        ESignLiveAPIObjects.Field fieldClient2 = new ESignLiveAPIObjects.Field();
        fieldClient2.extract = true;
        fieldClient2.name = 'client_date';		//match pdf field property name
        fieldClient2.type = 'INPUT';
        fieldClient2.subtype = 'LABEL';
        fieldClient2.binding = '{approval.signed}';
        
        //text field: first_name
        ESignLiveAPIObjects.Field fieldClient3 = new ESignLiveAPIObjects.Field();
        fieldClient3.extract = true;
        fieldClient3.name = 'first_name';		//match pdf field property name
        fieldClient3.type = 'INPUT';
        fieldClient3.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_first_name = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_first_name.required = true;
        FieldValidation_first_name.errorMessage = 'Please enter a valid first name.';
        FieldValidation_first_name.pattern = '^[\\sa-zA-Z]+$';
        fieldClient3.validation = FieldValidation_first_name;
        
        
        //text field: last_name
        ESignLiveAPIObjects.Field fieldClient4 = new ESignLiveAPIObjects.Field();
        fieldClient4.extract = true;
        fieldClient4.name = 'last_name';		//match pdf field property name
        fieldClient4.type = 'INPUT';
        fieldClient4.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_last_name = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_last_name.required = true;
        FieldValidation_last_name.errorMessage = 'Please enter a valid last name.';
        FieldValidation_last_name.pattern = '^[\\sa-zA-Z]+$';
        fieldClient4.validation = FieldValidation_last_name;
        
        
        //text field: address
        ESignLiveAPIObjects.Field fieldClient5 = new ESignLiveAPIObjects.Field();
        fieldClient5.extract = true;
        fieldClient5.name = 'address';		//match pdf field property name
        fieldClient5.type = 'INPUT';
        fieldClient5.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_address = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_address.required = true;
        FieldValidation_address.errorMessage = 'Please enter a valid address.';
        FieldValidation_address.pattern = '';
        fieldClient5.validation = FieldValidation_address;
        
        
        //text field: city
        ESignLiveAPIObjects.Field fieldClient6 = new ESignLiveAPIObjects.Field();
        fieldClient6.extract = true;
        fieldClient6.name = 'city';		//match pdf field property name
        fieldClient6.type = 'INPUT';
        fieldClient6.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_city = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_city.required = true;
        FieldValidation_city.errorMessage = 'Please enter a valid city.';
        FieldValidation_city.pattern = '^[\\sa-zA-Z]+$';
        fieldClient6.validation = FieldValidation_city;
        
        
        //text field: state
        ESignLiveAPIObjects.Field fieldClient7 = new ESignLiveAPIObjects.Field();
        fieldClient7.extract = true;
        fieldClient7.name = 'state';		//match pdf field property name
        fieldClient7.type = 'INPUT';
        fieldClient7.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_state = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_state.required = true;
        FieldValidation_state.errorMessage = 'Please enter a valid state.';
        FieldValidation_state.pattern = '^[\\sa-zA-Z]+$';
        FieldValidation_state.maxLength = 2;
        FieldValidation_state.minLength = 2;
        fieldClient7.validation = FieldValidation_state;
        
        
        //text field: zip
        ESignLiveAPIObjects.Field fieldClient8 = new ESignLiveAPIObjects.Field();
        fieldClient8.extract = true;
        fieldClient8.name = 'zip';		//match pdf field property name
        fieldClient8.type = 'INPUT';
        fieldClient8.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_zip = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_zip.required = true;
        FieldValidation_zip.errorMessage = 'Please enter a valid zip.';
        FieldValidation_zip.pattern = '^[-+]?[0-9]*\\.?[0-9]*$';
        FieldValidation_zip.maxLength = 5;
        FieldValidation_zip.minLength = 5;
        fieldClient8.validation = FieldValidation_zip;
        
        
        //text field: phone_number
        ESignLiveAPIObjects.Field fieldClient9 = new ESignLiveAPIObjects.Field();
        fieldClient9.extract = true;
        fieldClient9.name = 'phone_number';		//match pdf field property name
        fieldClient9.type = 'INPUT';
        fieldClient9.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_phone_number = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_phone_number.required = true;
        FieldValidation_phone_number.errorMessage = 'Please enter a valid phone number (XXX-XXX-XXXX)';
        FieldValidation_phone_number.pattern = '^[2-9]\\d{2}-\\d{3}-\\d{4}$';
        fieldClient9.validation = FieldValidation_phone_number;
        
        
        //text field: email
        ESignLiveAPIObjects.Field fieldClient10 = new ESignLiveAPIObjects.Field();
        fieldClient10.extract = true;
        fieldClient10.name = 'email';		//match pdf field property name
        fieldClient10.type = 'INPUT';
        fieldClient10.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_email = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_email.required = true;
        FieldValidation_email.errorMessage = 'Please enter a valid email.';
        FieldValidation_email.pattern = '^([a-z0-9_\\.-]+)@([\\da-z\\.-]+)\\.([a-z\\.]{2,6})$';
        fieldClient10.validation = FieldValidation_email;

        
        //text field: company
        ESignLiveAPIObjects.Field fieldClient11 = new ESignLiveAPIObjects.Field();
        fieldClient11.extract = true;
        fieldClient11.name = 'company';		//match pdf field property name
        fieldClient11.type = 'INPUT';
        fieldClient11.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_company = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_company.required = true;
        FieldValidation_company.errorMessage = 'Please enter a valid company.';
        FieldValidation_company.pattern = '^[\\sa-zA-Z]+$';
        fieldClient11.validation = FieldValidation_company;
        
        
        //text field: policy_number
        ESignLiveAPIObjects.Field fieldClient12 = new ESignLiveAPIObjects.Field();
        fieldClient12.extract = true;
        fieldClient12.name = 'policy_number';		//match pdf field property name
        fieldClient12.type = 'INPUT';
        fieldClient12.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_policy_number = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_policy_number.required = true;
        FieldValidation_policy_number.errorMessage = 'Please enter a valid policy number.';
        FieldValidation_policy_number.pattern = '^[-+]?[0-9]*\\.?[0-9]*$';
        fieldClient12.validation = FieldValidation_policy_number;
        
        
        //text field: country
        ESignLiveAPIObjects.Field fieldClient13 = new ESignLiveAPIObjects.Field();
        fieldClient13.extract = true;
        fieldClient13.name = 'country';		//match pdf field property name
        fieldClient13.type = 'INPUT';
        fieldClient13.subtype = 'TEXTFIELD';
        //set validator
        ESignLiveAPIObjects.FieldValidation FieldValidation_country = new ESignLiveAPIObjects.FieldValidation();
        FieldValidation_country.required = true;
        FieldValidation_country.errorMessage = 'Please enter a valid country.';
        FieldValidation_country.pattern = '^[\\sa-zA-Z]+$';
        fieldClient13.validation = FieldValidation_country;
        
        approvalForClient.fields = new List<ESignLiveAPIObjects.Field>{fieldClient1,fieldClient2,fieldClient3,fieldClient4,fieldClient5,fieldClient6,fieldClient7,fieldClient8,fieldClient9,fieldClient10,fieldClient11,fieldClient12,fieldClient13};
        
        
        //Approval for manager
        ESignLiveAPIObjects.Approval approvalForManager = new ESignLiveAPIObjects.Approval();
        approvalForManager.role = roleId1;
        approvalForManager.id = 'approvalForManager';
        
        //signature field for client
        ESignLiveAPIObjects.Field fieldManager1 = new ESignLiveAPIObjects.Field();
        fieldManager1.extract = true;
        fieldManager1.name = 'manager_signature';		//match pdf field property name
        fieldManager1.type = 'SIGNATURE';
        fieldManager1.subtype = 'CAPTURE';
        
        //date field for client
        ESignLiveAPIObjects.Field fieldManager2 = new ESignLiveAPIObjects.Field();
        fieldManager2.extract = true;
        fieldManager2.name = 'manager_date';		//match pdf field property name
        fieldManager2.type = 'INPUT';
        fieldManager2.subtype = 'LABEL';
        fieldManager2.binding = '{approval.signed}';
        
        approvalForManager.fields = new List<ESignLiveAPIObjects.Field>{fieldManager1,fieldManager2};
        
        
        document1.approvals = new List<ESignLiveAPIObjects.Approval>{approvalForClient,approvalForManager};
        
        pkg.documents = new List<ESignLiveAPIObjects.Document>{document1};    //add document
        
    	//Send package One Step
        String packageId = sdk.createPackage(pkg,documentBlobMap);
        System.debug('PackageId: ' + packageId);
    }
    
}